@@ -10,7 +10,7 @@ click.rich_click.USE_RICH_MARKUP = True
 click.rich_click.GROUP_ARGUMENTS_OPTIONS = True
 click.rich_click.SHOW_METAVARS_COLUMN = False
 click.rich_click.APPEND_METAVARS_HELP = True
-click.rich_click.MAX_WIDTH = 120
+click.rich_click.MAX_WIDTH = None
 click.rich_click.STYLE_OPTIONS_TABLE_BOX = "SIMPLE"
 click.rich_click.STYLE_COMMANDS_TABLE_SHOW_LINES = True
 click.rich_click.STYLE_COMMANDS_TABLE_PAD_EDGE = True
@@ -213,7 +213,7 @@ click.rich_click.OPTION_GROUPS = {
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 def cli():
     """
     [cyan]geNomad[/cyan]: Identification of mobile genetic elements
@@ -224,7 +224,7 @@ def cli():
 
 @cli.command(context_settings=CONTEXT_SETTINGS)
 @click.argument("destination", type=click.Path(path_type=Path, exists=True))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--keep",
     is_flag=True,
@@ -252,7 +252,7 @@ def download_database(destination, keep, verbose):
 @click.argument("input", type=click.Path(path_type=Path, exists=True))
 @click.argument("output", type=click.Path(path_type=Path))
 @click.argument("database", type=click.Path(path_type=Path, exists=True))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--cleanup",
     is_flag=True,
@@ -287,7 +287,7 @@ def download_database(destination, keep, verbose):
     "--sensitivity",
     "-s",
     type=click.FloatRange(min=0.0),
-    default=6.4,
+    default=4.0,
     show_default=True,
     help="""MMseqs2 marker search sensitivity. Higher values will annotate more
             proteins, but the search will be slower and consume more memory.""",
@@ -354,7 +354,7 @@ def annotate(
 @click.argument("input", type=click.Path(path_type=Path, exists=True))
 @click.argument("output", type=click.Path(path_type=Path))
 @click.argument("database", type=click.Path(path_type=Path, exists=True))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--restart",
     is_flag=True,
@@ -518,7 +518,7 @@ def find_proviruses(
 @click.argument("input", type=click.Path(path_type=Path, exists=True))
 @click.argument("output", type=click.Path(path_type=Path))
 @click.argument("database", type=click.Path(path_type=Path, exists=True))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--restart",
     is_flag=True,
@@ -557,7 +557,7 @@ def marker_classification(input, output, database, restart, threads, verbose):
 @cli.command(context_settings=CONTEXT_SETTINGS)
 @click.argument("input", type=click.Path(path_type=Path, exists=True))
 @click.argument("output", type=click.Path(path_type=Path))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--restart",
     is_flag=True,
@@ -612,7 +612,7 @@ def nn_classification(
 @cli.command(context_settings=CONTEXT_SETTINGS)
 @click.argument("input", type=click.Path(path_type=Path, exists=True))
 @click.argument("output", type=click.Path(path_type=Path))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--restart",
     is_flag=True,
@@ -641,7 +641,7 @@ def aggregated_classification(input, output, restart, verbose):
 @cli.command(context_settings=CONTEXT_SETTINGS)
 @click.argument("input", type=click.Path(path_type=Path, exists=True))
 @click.argument("output", type=click.Path(path_type=Path))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--composition",
     type=click.Choice(["auto", "metagenome", "virome"], case_sensitive=False),
@@ -678,7 +678,7 @@ def score_calibration(input, output, composition, force_auto, verbose):
 @cli.command(context_settings=CONTEXT_SETTINGS)
 @click.argument("input", type=click.Path(path_type=Path, exists=True))
 @click.argument("output", type=click.Path(path_type=Path))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--verbose/--quiet",
     "-v/-q",
@@ -788,7 +788,7 @@ def summary(
 @click.argument("input", type=click.Path(path_type=Path, exists=True))
 @click.argument("output", type=click.Path(path_type=Path))
 @click.argument("database", type=click.Path(path_type=Path, exists=True))
-@click.version_option()
+@click.version_option(prog_name="geNomad")
 @click.option(
     "--restart",
     is_flag=True,
@@ -845,7 +845,7 @@ def summary(
     "--sensitivity",
     "-s",
     type=click.FloatRange(min=0.0),
-    default=6.4,
+    default=4.0,
     show_default=True,
     help="""MMseqs2 marker search sensitivity. Higher values will annotate more
             proteins, but the search will be slower and consume more memory.""",
