@@ -448,11 +448,14 @@ def main(
         )
         plasmid_name_set = set(plasmid_name_array)
         virus_name_set = set(virus_name_array)
-        console.log("Plasmids and viruses were identified.")
+        console.log(
+            f"{len(plasmid_name_array):,} plasmid(s) and "
+            f"{len(virus_name_array):,} virus(es) were identified."
+        )
 
     with console.status("Writing nucleotide FASTA files."):
         length_dict = {}
-        topology_dict = {}
+        terminal_repeat_dict = {}
         with open(outputs.summary_plasmid_sequences_output, "w") as fout1, open(
             outputs.summary_virus_sequences_output, "w"
         ) as fout2:
@@ -460,20 +463,20 @@ def main(
                 if seq.accession in plasmid_name_set:
                     length_dict[seq.accession] = len(seq)
                     if seq.has_dtr():
-                        topology_dict[seq.accession] = "DTR"
+                        terminal_repeat_dict[seq.accession] = "DTR"
                     elif seq.has_itr():
-                        topology_dict[seq.accession] = "ITR"
+                        terminal_repeat_dict[seq.accession] = "ITR"
                     else:
-                        topology_dict[seq.accession] = "Linear"
+                        terminal_repeat_dict[seq.accession] = "No terminal repeats"
                     fout1.write(str(seq))
                 elif seq.accession in virus_name_set:
                     length_dict[seq.accession] = len(seq)
                     if seq.has_dtr():
-                        topology_dict[seq.accession] = "DTR"
+                        terminal_repeat_dict[seq.accession] = "DTR"
                     elif seq.has_itr():
-                        topology_dict[seq.accession] = "ITR"
+                        terminal_repeat_dict[seq.accession] = "ITR"
                     else:
-                        topology_dict[seq.accession] = "Linear"
+                        terminal_repeat_dict[seq.accession] = "No terminal repeats"
                     fout2.write(str(seq))
             if include_provirus:
                 for seq in sequence.read_fasta(
@@ -481,7 +484,7 @@ def main(
                 ):
                     if seq.accession in virus_name_set:
                         length_dict[seq.accession] = len(seq)
-                        topology_dict[seq.accession] = "Provirus"
+                        terminal_repeat_dict[seq.accession] = "Provirus"
                         fout2.write(str(seq))
         console.log(
             "Nucleotide sequences were written to "
@@ -513,18 +516,19 @@ def main(
 
         with console.status("Writting gene annotation data."):
             conjscan_genes_dict = defaultdict(list)
+            amr_genes_dict = defaultdict(list)
             with open(outputs.summary_plasmid_genes_output, "w") as fout1, open(
                 outputs.summary_virus_genes_output, "w"
             ) as fout2:
                 fout1.write(
-                    "gene\tstart\tend\tlength\tstrand\tgc_content\tgenetic_code\trbs_motif\t"
-                    "marker\tevalue\tbitscore\tuscg\tplasmid_hallmark\tvirus_hallmark\ttaxid\t"
-                    "taxname\tannotation_conjscan\tannotation_accessions\tannotation_description\n"
+                    "gene\tstart\tend\tlength\tstrand\tgc_content\tgenetic_code\trbs_motif\tmarker\t"
+                    "evalue\tbitscore\tuscg\tplasmid_hallmark\tvirus_hallmark\ttaxid\ttaxname\t"
+                    "annotation_conjscan\tannotation_amr\tannotation_accessions\tannotation_description\n"
                 )
                 fout2.write(
-                    "gene\tstart\tend\tlength\tstrand\tgc_content\tgenetic_code\trbs_motif\t"
-                    "marker\tevalue\tbitscore\tuscg\tplasmid_hallmark\tvirus_hallmark\ttaxid\t"
-                    "taxname\tannotation_conjscan\tannotation_accessions\tannotation_description\n"
+                    "gene\tstart\tend\tlength\tstrand\tgc_content\tgenetic_code\trbs_motif\tmarker\t"
+                    "evalue\tbitscore\tuscg\tplasmid_hallmark\tvirus_hallmark\ttaxid\ttaxname\t"
+                    "annotation_conjscan\tannotation_amr\tannotation_accessions\tannotation_description\n"
                 )
                 for line in utils.read_file(
                     outputs.annotate_genes_output, skip_header=True
@@ -534,6 +538,8 @@ def main(
                         fout1.write(line)
                         if line.split("\t")[16] != "NA":
                             conjscan_genes_dict[seq_name].append(line.split("\t")[16])
+                        if line.split("\t")[17] != "NA":
+                            amr_genes_dict[seq_name].append(line.split("\t")[17])
                     elif seq_name in virus_name_set:
                         fout2.write(line)
                 if include_provirus:
@@ -580,7 +586,7 @@ def main(
         with open(outputs.summary_plasmid_output, "w") as fout:
             fout.write(
                 "seq_name\tlength\ttopology\tn_genes\tgenetic_code\tplasmid_score\t"
-                "fdr\tn_hallmarks\tmarker_enrichment\tconjugation_genes\n"
+                "fdr\tn_hallmarks\tmarker_enrichment\tconjugation_genes\tamr_genes\n"
             )
             for seq_name, score, fdr in itertools.zip_longest(
                 plasmid_name_array,
@@ -589,7 +595,7 @@ def main(
                 fillvalue="NA",
             ):
                 length = length_dict.get(seq_name, "NA")
-                topology = topology_dict.get(seq_name, "NA")
+                terminal_repeat = terminal_repeat_dict.get(seq_name, "NA")
                 n_genes = n_genes_dict.get(seq_name, "NA")
                 genetic_code = genetic_code_dict.get(seq_name, "NA")
                 score = f"{score:.4f}"
@@ -605,26 +611,32 @@ def main(
                         conjugation_genes = ";".join(conjugation_genes)
                     else:
                         conjugation_genes = "NA"
+                    amr_genes = amr_genes_dict.get(seq_name, [])
+                    if len(amr_genes):
+                        amr_genes = ";".join(amr_genes)
+                    else:
+                        amr_genes = "NA"
                 else:
                     marker_enrichment = "NA"
                     n_hallmarks = "NA"
                     conjugation_genes = "NA"
+                    amr_genes = "NA"
                 fout.write(
-                    f"{seq_name}\t{length}\t{topology}\t{n_genes}\t{genetic_code}\t{score}\t"
-                    f"{fdr}\t{n_hallmarks}\t{marker_enrichment}\t{conjugation_genes}\n"
+                    f"{seq_name}\t{length}\t{terminal_repeat}\t{n_genes}\t{genetic_code}\t{score}\t"
+                    f"{fdr}\t{n_hallmarks}\t{marker_enrichment}\t{conjugation_genes}\t{amr_genes}\n"
                 )
 
         # Write virus summary file
         with open(outputs.summary_virus_output, "w") as fout:
             fout.write(
-                "seq_name\tlength\ttopology\tcoordinates\tn_genes\tgenetic_code\tvirus_score\t"
-                "fdr\tn_hallmarks\tmarker_enrichment\ttaxonomy\n"
+                "seq_name\tlength\ttopology\tcoordinates\tn_genes\tgenetic_code\t"
+                "virus_score\tfdr\tn_hallmarks\tmarker_enrichment\ttaxonomy\n"
             )
             for seq_name, score, fdr in itertools.zip_longest(
                 virus_name_array, virus_score_array, virus_fdr_array, fillvalue="NA"
             ):
                 length = length_dict.get(seq_name, "NA")
-                topology = topology_dict.get(seq_name, "NA")
+                terminal_repeat = terminal_repeat_dict.get(seq_name, "NA")
                 coord = provirus_coord_dict.get(seq_name, "NA")
                 coord = "-".join(map(str, coord)) if isinstance(coord, tuple) else coord
                 n_genes = n_genes_dict.get(seq_name, "NA")
@@ -643,7 +655,7 @@ def main(
                     n_hallmarks = "NA"
                     taxonomy = "NA"
                 fout.write(
-                    f"{seq_name}\t{length}\t{topology}\t{coord}\t{n_genes}\t{genetic_code}\t"
+                    f"{seq_name}\t{length}\t{terminal_repeat}\t{coord}\t{n_genes}\t{genetic_code}\t"
                     f"{score}\t{fdr}\t{n_hallmarks}\t{marker_enrichment}\t{taxonomy}\n"
                 )
 
@@ -652,3 +664,5 @@ def main(
             f"[green]{outputs.summary_plasmid_output.name}[/green] and "
             f"[green]{outputs.summary_virus_output.name}[/green]."
         )
+
+        console.log("geNomad summary finished!", style="yellow")
